@@ -15,7 +15,15 @@ test_that("transmute_sd works with other dplyr verbs as expected.", {
 
     expect_identical(ans, expected)
 
+    ans <- DT %>%
+        group_by(gear, carb) %>%
+        where(vs == 0) %>%
+        transmute_sd(function(x) { floor(x) / ceiling(max(x)) }, .SDcols = ends_with("t"))
+
+    expect_identical(ans, expected)
+
     foo <- function(x) { floor(x) / ceiling(max(x)) }
+
     ans <- DT %>%
         start_expr %>%
         transmute_sd(foo, .SDcols = ends_with("t")) %>%
@@ -24,4 +32,11 @@ test_that("transmute_sd works with other dplyr verbs as expected.", {
         end_expr
 
     expect_identical(ans, expected)
+
+    ans <- DT %>%
+        group_by(gear, carb) %>%
+        where(vs == 0) %>%
+        transmute_sd(foo, .SDcols = ends_with("t"))
+
+    expect_identical(ans, expected)
 })
