@@ -45,7 +45,7 @@ test_that("Semi join works.", {
 
     expect_identical(ans, expected)
 
-    expected <- data.table::setDT(dplyr::semi_join(as.data.frame(paypal), website, by = c(payment_id = "session_id")))
+    expected <- data.table::as.data.table(dplyr::semi_join(as.data.frame(paypal), website, by = c(payment_id = "session_id")))
     data.table::setkey(expected, name, purchase_time)
 
     expect_identical(ans, expected)
@@ -63,14 +63,14 @@ test_that("Eager semi_join works.", {
 
 test_that("semi_join can delegate to data.frame method when necessary.", {
     .expr <- rlang::expr((function() {
-        local_rhs <- data.table::setDT(!!rhs)
-        semi_join(data.table::setDT(!!lhs), local_rhs, by = "x")
+        local_rhs <- data.table::as.data.table(!!rhs)
+        semi_join(data.table::as.data.table(!!lhs), local_rhs, by = "x")
     })())
 
     expect_warning(ans <- eval(.expr, envir = asNamespace("rex")), "table.express")
     expect_equal(ans, dplyr:::semi_join.data.frame(lhs, rhs, "x"))
 
-    .expr <- rlang::expr(semi_join(data.table::setDT(!!lhs), data.table::setDT(!!rhs), x))
+    .expr <- rlang::expr(semi_join(data.table::as.data.table(!!lhs), data.table::as.data.table(!!rhs), x))
     ans_from_workaround <- eval(.expr, envir = asNamespace("rex"))
     expect_equal(ans_from_workaround, semi_join(lhs, rhs, x))
 })
